<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package finpro
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function finpro_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'finpro_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function finpro_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'finpro_pingback_header' );


function getBrightness($gdHandle) {
	$width = imagesx($gdHandle);
	$height = imagesy($gdHandle);

	$totalBrightness = 0;

	for ($x = 0; $x < $width; $x++) {
		for ($y = 0; $y < $height; $y++) {
			$rgb = imagecolorat($gdHandle, $x, $y);

			$red = ($rgb >> 16) & 0xFF;
			$green = ($rgb >> 8) & 0xFF;
			$blue = $rgb & 0xFF;

			$totalBrightness += (max($red, $green, $blue) + min($red, $green, $blue)) / 2;
		}
	}

	imagedestroy($gdHandle);

	return ($totalBrightness / ($width * $height)) / 2.55;
}

function finpro_thumbnail_brightness($src) {
	return getBrightness( imagecreatefromjpeg($src) );
}